@@ -14,34 +14,21 @@
  * limitations under the License.
  */
 
-/******************************************************************************
-globus_l_gass_transfer_http.h
- 
-Description:
-    This header defines the prototypes for the local functions in the
-    http protocol module source file
- 
-CVS Information:
- 
-    $Source: /home/globdev/CVS/globus-packages/gass/transfer/source/library/globus_l_gass_transfer_http.h,v $
-    $Date: 2008/09/25 18:41:50 $
-    $Revision: 1.18 $
-    $Author: bester $
-******************************************************************************/
-#ifndef GLOBUS_GASS_INCLUDE_GLOBUS_L_GASS_TRANSFER_HTTP_H
-#define GLOBUS_GASS_INCLUDE_GLOBUS_L_GASS_TRANSFER_HTTP_H
+#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
+
+/**
+ * @file globus_l_gass_transfer_http.h
+ * @brief http protocol module
+ *
+ * This header defines the prototypes for the local functions in the
+ * http protocol module source file
+ */
+#ifndef GLOBUS_L_GASS_TRANSFER_HTTP_H
+#define GLOBUS_L_GASS_TRANSFER_HTTP_H
 
-#ifndef EXTERN_C_BEGIN
 #ifdef __cplusplus
-#define EXTERN_C_BEGIN extern "C" {
-#define EXTERN_C_END }
-#else
-#define EXTERN_C_BEGIN
-#define EXTERN_C_END
+extern "C" {
 #endif
-#endif
-
-EXTERN_C_BEGIN
 
 /******************************************************************************
 			  Module Specific Constants
@@ -657,6 +644,10 @@ void
 globus_l_gass_transfer_http_listener_close(
     globus_gass_transfer_http_listener_proto_t * proto);
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
-#endif /* GLOBUS_GASS_INCLUDE_GLOBUS_L_GASS_TRANSFER_HTTP_H */
+#endif /* GLOBUS_L_GASS_TRANSFER_HTTP_H */
+
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
